pub struct EmptyResponse {
pub errors: Option<Errors>,
}Expand description
Empty response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- delete groups (response)
- delete group items (response)
Fields
errors: Option<Errors>Apiary error details