pub struct Group {
pub snippet: Option<GroupSnippet>,
pub kind: Option<String>,
pub errors: Option<Errors>,
pub etag: Option<String>,
pub content_details: Option<GroupContentDetails>,
pub id: Option<String>,
}Expand description
A group.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list groups (none)
- update groups (request|response)
- insert groups (request|response)
- delete groups (none)
Fields
snippet: Option<GroupSnippet>The snippet object contains basic information about the group, including
its creation date and name.
kind: Option<String>Identifies the API resource’s type. The value will be youtube#group.
errors: Option<Errors>Apiary error details
etag: Option<String>The Etag of this resource.
content_details: Option<GroupContentDetails>The contentDetails object contains additional information about the
group, such as the number and type of items that it contains.
id: Option<String>The ID that YouTube uses to uniquely identify the group.