pub struct ListGroupItemsResponse {
pub items: Option<Vec<GroupItem>>,
pub kind: Option<String>,
pub etag: Option<String>,
pub errors: Option<Errors>,
}Expand description
Response message for GroupsService.ListGroupItems.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list group items (response)
Fields
items: Option<Vec<GroupItem>>A list of groups that match the API request parameters. Each item in the
list represents a groupItem resource.
kind: Option<String>Identifies the API resource’s type. The value will be
youtube#groupItemListResponse.
etag: Option<String>The Etag of this resource.
errors: Option<Errors>Apiary error details